<?php

/**
 * @file
 * Editor hooks implemented by the Editor Test module.
 */

/**
 * Implements hook_editor_info().
 */
function editor_test_editor_info() {
  $editors['trex'] = array(
    'label' => t('TRex Editor'),
    'supports_content_filtering' => TRUE,
    'supports_inline_editing' => TRUE,
    'is_xss_safe' => FALSE,
    'supported_element_types' => array(
      "textarea"
    ),
    'default settings' => array(
      'stumpy_arms' => TRUE,
    ),
    'file' => 'includes/editor_test.admin.inc',
    'libraries callback' => 'editor_test_trex_get_libraries',
    'submit callback' => 'editor_test_trex_settings_form_submit',
    'settings callback' => 'editor_test_trex_settings_form',
    'js settings callback' => 'editor_test_trex_get_js_settings',
  );

  $editors['unicorn'] = array(
    'label' => t('Unicorn Editor'),
    'supports_content_filtering' => TRUE,
    'supports_inline_editing' => TRUE,
    'is_xss_safe' => FALSE,
    'supported_element_types' => array(
      "textarea",
      "textfield",
    ),
    'default settings' => array(
      'ponies_too' => TRUE,
    ),
    'file' => 'includes/editor_test.admin.inc',
    'libraries callback' => 'editor_test_unicorn_get_libraries',
    'submit callback' => 'editor_test_unicorn_settings_form_submit',
    'settings callback' => 'editor_test_unicorn_settings_form',
    'js settings callback' => 'editor_test_unicorn_get_js_settings',
  );

  return $editors;
}

/**
 * Editor JS settings callback; Add TRex settings to the page for a format.
 *
 * @param object $format
 *   The filter format object for which TRex is adding its settings.
 *
 * @return array
 *   An associative array of TRex settings.
 */
function editor_test_trex_get_js_settings($format) {
  $js_settings = array();
  $settings = $format->editor_settings;
  if ($settings['stumpy_arms']) {
    $js_settings['doMyArmsLookStumpy'] = TRUE;
  }
  return $js_settings;
}

/**
 * Returns a list of libraries this plugin requires.
 *
 * These libraries will be attached to the text_format element on which the
 * editor is being loaded.
 *
 * @param $format
 *   An object representing a text format.
 *
 * @return array
 *   An array of libraries suitable for usage in a render API #attached
 *   property.
 */
function editor_test_trex_get_libraries($format) {
  return array(
    array('editor_test', 'trex'),
  );
}

/**
 * Editor JS settings callback; Add Unicorn settings to the page for a format.
 *
 * @param object $format
 *   The filter format object for which Unicorn is adding its settings.
 *
 * @return array
 *   An associative array of Unicorn settings.
 */
function editor_test_unicorn_get_js_settings($format) {
  $js_settings = array();
  $settings = $format->editor_settings;
  if ($settings['ponies_too']) {
    $js_settings['ponyModeEnabled'] = TRUE;
  }
  return $js_settings;
}

/**
 * Returns a list of libraries this plugin requires.
 *
 * These libraries will be attached to the text_format element on which the
 * editor is being loaded.
 *
 * @param $format
 *   An object representing a text format.
 *
 * @return array
 *   An array of libraries suitable for usage in a render API #attached
 *   property.
 */
function editor_test_unicorn_get_libraries($format) {
  return array(
    array('editor_test', 'unicorn'),
  );
}
